@@ -14,7 +14,7 @@ from .common import recursively_extract, table_node_to_tagged_cells, clear_text
 EXPORT_ATTRIBUTES = [
     'name', 'urlname', 'title', 'article', 'part_of_speech', 'usage',
     'frequency', 'word_separation', 'meaning_overview', 'origin', 'compounds',
-    'grammar_raw', 'synonyms', 'words_before', 'words_after'
+    'grammar_raw', 'synonyms', 'words_before', 'words_after', 'phonetic', 'alternative_spellings'
 ]
 
 gettext.install('duden', os.path.join(os.path.dirname(__file__), 'locale'))
@@ -53,12 +53,20 @@ class DudenWord():
         """
         Word without article
         """
+
+        # Find span with class "lemma__main"
+        title_element = self.soup.find('span', {"class": "lemma__main"})
+        if title_element is not None:
+            # remove soft hyphens "\xad" and return
+            return clear_text(title_element.get_text())
+
+        #  if the title_element does not exist, we fall back to the old method
         if self.part_of_speech is not None and 'Substantiv' not in self.part_of_speech:
             return self.title
         if ', ' not in self.title:
             return self.title
 
-        name, _ = self.title.split(', ')
+        name, _ = self.title.split(', ', 1)
         return name
 
     @property
@@ -66,7 +74,7 @@ class DudenWord():
         """
         Return unique representation of the word used in duden.de urls
         """
-        return self.soup.head.link.attrs['href'].split('/')[-1]
+        return self.soup.head.find('link', rel='canonical').attrs['href'].split('/')[-1]
 
     @property
     def revision_url(self):
@@ -88,12 +96,19 @@ class DudenWord():
         """
         Word article
         """
+        # Find span with class "lemma__determiner"
+        article_element = self.soup.find('span', {"class": "lemma__determiner"})
+        if article_element is not None:
+            # remove soft hyphens "\xad" and return
+            return clear_text(article_element.get_text())
+
+        #  if the article_element does not exist, we fall back to the old method
         if self.part_of_speech is not None and 'Substantiv' not in self.part_of_speech:
             return None
         if ', ' not in self.title:
             return None
 
-        _, article = self.title.split(', ')
+        _, article = self.title.split(', ', 1)
         return article
 
     def _find_tuple_dl(self, key, element=None):
@@ -174,6 +189,7 @@ class DudenWord():
 
         # 1. remove examples
         for dl_node in section.find_all('dl', class_='note'):
+            # pylint: disable=condition-evals-to-constant
             if True or dl_node.dt.text == 'Beispiele':
                 dl_node.extract()
 
@@ -292,7 +308,7 @@ class DudenWord():
 
         Used e.g. for creating test data.
         """
-        worddict = dict()
+        worddict = {}
         for attribute in EXPORT_ATTRIBUTES:
             worddict[attribute] = getattr(self, attribute, None)
 
@@ -344,3 +360,26 @@ class DudenWord():
     def words_after(self):
         """Returns 5 words after this one in duden database"""
         return [name for name, _ in self.before_after_structure['Im Alphabet danach']]
+
+    @property
+    def phonetic(self):
+        """
+        Returns pronunciation of the word in phonetic notation.
+        See: https://en.wikipedia.org/wiki/International_Phonetic_Alphabet
+        """
+        ipa = self.soup.find('span', {"class": "ipa"})
+        if ipa is not None:
+            return ipa.get_text()
+
+        return None
+
+    @property
+    def alternative_spellings(self):
+        """
+        Returns alternate spellings
+        """
+        alternative_spellings = self.soup.find_all('span', {"class": "lemma__alt-spelling"})
+        if alternative_spellings is None:
+            return None
+
+        return [spelling.get_text() for spelling in alternative_spellings]
